const std = @import("std");

const dbg_print = std.debug.print;
const eql = std.mem.eql;


pub const SongData = struct {
    track_url: []const u8,
    track_title: []const u8,
};

pub fn decode_song_data(allocator: std.mem.Allocator, json_string: []const u8) !SongData {
    const parsed = try std.json.parseFromSlice(std.json.Value, allocator, json_string, .{});
    defer parsed.deinit();

    const json_data = parsed.value;
    var track_url: ?[]const u8 = null;
    var track_title: ?[]const u8 = null;

    if (json_data == .array) {
        for (json_data.array.items) |item| {
            if (item == .object) {
                if (item.object.get("OriginalTrackUrl")) |url_value| {
                    if (url_value == .string) {
                        track_url = try allocator.dupe(u8, url_value.string);
                    }
                }
                if (item.object.get("title")) |title_value| {
                    if (title_value == .string) {
                        track_title = try allocator.dupe(u8, title_value.string);
                    }
                }
            }
        }
    }
    if (track_url) |url| {
        if (track_title) |title| {
            return SongData{
                .track_url = url,
                .track_title = title,
            };
        }
    }
    return error.Unexpected;
}


pub fn decode_album_data() void {
    unreachable;
}

pub fn decode_track_results() void {
    unreachable;
}

pub fn decode_album_results() void {
    unreachable;
}
